==> landtax-1.0.0-20160518.023814-5-sources.jar: cn/gtmap/landtax/entity/SwDjJbbBase.java <==
package cn.gtmap.landtax.entity;

import javax.persistence.Column;
import javax.persistence.MappedSuperclass;

/**
 * 税务纳税人公共信息
 *
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2014/6/25
 */
@MappedSuperclass
public abstract class SwDjJbbBase{

    @Column
    private String glbm;
    @Column
    private String nsrmc;
    @Column
    private String zgkgDm;
    @Column
    private String zgkgMc;
    @Column
    private String sgyDm;
    @Column
    private String sgyMc;
    @Column
    private String fddbr;
    @Column
    private String lxdh;
    @Column
    private String zclxDm;
    @Column
    private String zclxMc;
    @Column
    private String hyDm;
    @Column
    private String hyMc;
    @Column
    private String zcdz;

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getZgkgMc() {
        return zgkgMc;
    }

    public void setZgkgMc(String zgkgMc) {
        this.zgkgMc = zgkgMc;
    }

    public String getSgyMc() {
        return sgyMc;
    }

    public void setSgyMc(String sgyMc) {
        this.sgyMc = sgyMc;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getZclxDm() {
        return zclxDm;
    }

    public void setZclxDm(String zclxDm) {
        this.zclxDm = zclxDm;
    }

    public String getZclxMc() {
        return zclxMc;
    }

    public void setZclxMc(String zclxMc) {
        this.zclxMc = zclxMc;
    }

    public String getHyDm() {
        return hyDm;
    }

    public void setHyDm(String hyDm) {
        this.hyDm = hyDm;
    }

    public String getHyMc() {
        return hyMc;
    }

    public void setHyMc(String hyMc) {
        this.hyMc = hyMc;
    }

    public String getZcdz() {
        return zcdz;
    }

    public void setZcdz(String zcdz) {
        this.zcdz = zcdz;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }

    public String getSgyDm() {
        return sgyDm;
    }

    public void setSgyDm(String sgyDm) {
        this.sgyDm = sgyDm;
    }
}

==> landtax-1.0.0-20160602.090753-7-sources.jar: cn/gtmap/landtax/entity/SwDjJbbBase.java <==
package cn.gtmap.landtax.entity;

import javax.persistence.*;

/**
 * 税务基本表
 *
 * @author <a href="mailto:zhouzhiwei@gtmap.cn">zhouzhiwei</a>
 * @version 1.0, 2015/8/26
 */
@MappedSuperclass
public abstract class SwDjJbbBase {
    @Column
    private String glbm; // 管理编码

    @Column
    private String nsrmc; // 纳税人名称

    @Column
    private String zclxDm; // 注册类型代码

    @Column
    private String zclxMc; // 注册类型名称

    @Column
    private String hyDm; // 行业代码

    @Column
    private String hyMc; // 行业名称

    @Column
    private String zcdz; // 注册地址

    @Column
    private String fddbr; // 法定代表人

    @Column
    private String lxdh; // 联系电话

    @Column
    private String sgyDm; // 税管员代码

    @Column
    private String sgyMc; // 税管员名称

    @Column
    private String zgkgDm; // 主管税务机关代码

    @Column
    private String zgkgMc; // 主管税务机关名称

    @Column
    private String nsrztDm; // 纳税人状态代码

    @Column
    private String nsrztMc; // 纳税人状态名称

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getZclxDm() {
        return zclxDm;
    }

    public void setZclxDm(String zclxDm) {
        this.zclxDm = zclxDm;
    }

    public String getZclxMc() {
        return zclxMc;
    }

    public void setZclxMc(String zclxMc) {
        this.zclxMc = zclxMc;
    }

    public String getHyDm() {
        return hyDm;
    }

    public void setHyDm(String hyDm) {
        this.hyDm = hyDm;
    }

    public String getHyMc() {
        return hyMc;
    }

    public void setHyMc(String hyMc) {
        this.hyMc = hyMc;
    }

    public String getZcdz() {
        return zcdz;
    }

    public void setZcdz(String zcdz) {
        this.zcdz = zcdz;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getSgyDm() {
        return sgyDm;
    }

    public void setSgyDm(String sgyDm) {
        this.sgyDm = sgyDm;
    }

    public String getSgyMc() {
        return sgyMc;
    }

    public void setSgyMc(String sgyMc) {
        this.sgyMc = sgyMc;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }

    public String getZgkgMc() {
        return zgkgMc;
    }

    public void setZgkgMc(String zgkgMc) {
        this.zgkgMc = zgkgMc;
    }

    public String getNsrztDm() {
        return nsrztDm;
    }

    public void setNsrztDm(String nsrztDm) {
        this.nsrztDm = nsrztDm;
    }

    public String getNsrztMc() {
        return nsrztMc;
    }

    public void setNsrztMc(String nsrztMc) {
        this.nsrztMc = nsrztMc;
    }
}
